@@ -24,6 +24,8 @@ from dkist_processing_pac.optics.telescope import load_TM_database
 from dkist_processing_pac.optics.telescope import Telescope
 
 GLOBAL_PARAMS = ["Q_in", "U_in", "V_in"]
+TELESCOPE_PARAMS = ["x12", "t12", "x34", "t34", "x56", "t56"]
+CU_PARAMS = ["t_pol", "t_ret", "ret0h", "ret045", "ret0r"]
 
 
 class PolcalDresserParameters:
@@ -225,9 +227,7 @@ class PolcalDresserParameters:
             db_file=tm_db_file, wavelength=wavelength, mean_time=mean_time
         )
 
-        tm_par_names = ["x12", "t12", "x34", "t34", "x56", "t56"]
-
-        for p in tm_par_names:
+        for p in TELESCOPE_PARAMS:
             if self.fit_TM:
                 val = tm_init_pars["params"][p][wave_idx, 1]
             else:
@@ -279,6 +279,18 @@ class PolcalDresserParameters:
         # Just in case
         params["modmat_0I"].set(value=1)
 
+    def fix_global_CU_params(self, global_fit_params: Parameters):
+        """Fix."""
+        global_par_dict = global_fit_params.valuesdict()
+        num_points = np.prod(self.fov_shape)
+        for i in range(num_points):
+            idx = np.unravel_index(i, self.fov_shape)
+            params = self.init_params[idx]
+            for par in CU_PARAMS:
+                for d in range(self.dresser.numdrawers):
+                    par_name = f"{par}_CS{d:02n}"
+                    params[par_name].set(value=global_par_dict[par_name], vary=False)
+
 
 class NdParameterArray:
     """Store single lmfit `Parameters` objects for an N-dimensional set of points.
@@ -305,3 +317,14 @@ class NdParameterArray:
 
     def _get_true_idx(self, multi_idx: Tuple[Union[int, np.ndarray], ...]) -> int:
         return int(np.ravel_multi_index(multi_idx, self.fake_shape))
+
+    @property
+    def first_parameters(self) -> Parameters:
+        """Return the first set of Parameters.
+
+        This exists because the Calibration Unit and Telescope need to be initialized from some parameters and, without
+        a prior knowledge of eactly the shape of the NdParameterArray, the first (and perhaps only) Parameter is as good
+        as any. This is OK because the CU and Telescope initialization only relies on parameters that are the same for all
+        FOV points anyway.
+        """
+        return self._all_parameters[0]
